module Fastlane
  module Actions
    class ParseJsonAction < Action
      def self.run(params)
        file_path = params[:path]
        file_content = File.read(file_path)
        return JSON.parse(file_content)
      end

      def self.description
        "Parse a JSON file"
      end

      def self.authors
        ["KrauseFx"]
      end

      def self.return_value
        "The content of the JSON file"
      end

      def self.available_options
        [
          FastlaneCore::ConfigItem.new(key: :path,
                                  env_name: "PARSE_JSON_PATH",
                               description: "Path to the JSON file",
                                  optional: false,
                                  verify_block: proc do |value|
                                    UI.user_error!("Couldn't find given file") unless File.exist?(value)
                                  end,
                                      type: String)
        ]
      end

      def self.is_supported?(platform)
        true
      end
    end
  end
end
